@@ -18,7 +18,7 @@
 #ifndef ALERTDIALOG_H
 #define ALERTDIALOG_H
 
-#include <ntqwidget.h>
+#include <tqwidget.h>
 #include "AlertDlg.h"
 
 /**
