@@ -19,7 +19,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <ntqfile.h>
+#include <tqfile.h>
 
 #include <tdeconfig.h>
 #include <ksavefile.h>
@@ -59,15 +59,15 @@ ConfigList::ConfigList() : TQObject()
 
 }
 
-int ConfigList::compareItems( TQCollection::Item item1, TQCollection::Item item2 )
+int ConfigList::compareItems( TQPtrCollection::Item item1, TQPtrCollection::Item item2 )
 {
   ConfigElem* p1 = (ConfigElem*)item1;
   ConfigElem* p2 = (ConfigElem*)item2;
 
-  return strcmp( p1->getAccountName(), p2->getAccountName() );
+  return TQString::compare(p1->getAccountName(), p2->getAccountName());
 }
 
-TQCollection::Item ConfigList::newItem( TQCollection::Item item )
+TQPtrCollection::Item ConfigList::newItem( TQPtrCollection::Item item )
 {
   return new ConfigElem( (ConfigElem*)item );
 }
@@ -174,7 +174,7 @@ void ConfigList::beep ()
 void ConfigList::playSound ()
 {
 	if (m_bSound)
-  	playSound (m_strSoundFile);
+	playSound (m_strSoundFile.local8Bit());
 }
 
 void ConfigList::playSound (const char* file)
@@ -1200,4 +1200,4 @@ void ConfigList::refreshFilterSetup( )
 
 }
 
-
+#include "configlist.moc"
