@@ -13,9 +13,9 @@
 #define FILTERLOGVIEW_H
 
 //TQt headers
-#include <ntqlabel.h>
-#include <ntqlayout.h>
-#include <ntqtooltip.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
 
 //KDE headers
 #include <kdialogbase.h>
