@@ -99,7 +99,7 @@ void KShowMailApp::timerEvent (TQTimerEvent *)
   {
     TQTime time;
     time = time.addSecs (m_nSecondsToGo--);
-    TQCString msg (i18n("Autorefresh: %1").arg (time.toString()));
+    TQCString msg (i18n("Autorefresh: %1").arg(time.toString()).utf8());
     statusBar()->changeItem( msg, STATUSBAR_FIELD_NEXT_REFRESH );
   }
   else
@@ -859,3 +859,4 @@ void KShowMailApp::slotAddToBlacklist( )
   m_ConfigList.refreshFilterSetup();
 }
 
+#include "kshowmail.moc"
