@@ -13,8 +13,8 @@
 #define SHOWHEADERDIALOG_H
 
 //QT headers
-#include <ntqlayout.h>
-#include <ntqlabel.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
 
 //KDE headers
 #include <kdialogbase.h>
